@@ -1,8 +1,5 @@
-standardize <- function (object, unchanged=NULL,
+standardize.default <- function(call, unchanged=NULL,
                          standardize.y=FALSE, binary.inputs="center"){
-
-  call <- object$call
-  if (is.null(call)) call <- object@call
   form <- call$formula
   varnames <- all.vars (form)
   n.vars <- length (varnames)
@@ -15,10 +12,10 @@ standardize <- function (object, unchanged=NULL,
   }
   for (i in 2:n.vars){
     v <- varnames[i]
-    if (is.null(call$data)){   # if regression is using the regular workspace
+    if (is.null(call$data)) {
       thedata <- get(v)
     }
-    else {                     # if the regression is using a data frame
+    else {
       thedata <- get(as.character(call$data))[[v]]
     }
     if (is.na(match(v,unchanged))){
@@ -40,30 +37,25 @@ standardize <- function (object, unchanged=NULL,
     paste ("c", varnames, sep=".")))
   transformed.variables <- (1:n.vars)[transform!="leave.alone"]
 
-  if (is.null(call$data)){
-#
-# If the regression is using the regular workspace, define the new variables
-#
-    for (i in transformed.variables){
-      assign (varnames.new[i], rescale(get(varnames[i]), binary.inputs))
+
+  #Define the new variables
+  if (is.null(call$data)) {
+    for (i in transformed.variables) {
+      assign(varnames.new[i], rescale(get(varnames[i]), binary.inputs))
     }
   }
   else {
-#
-# If the regression uses a data frame, define the new variables there
-#
     newvars <- NULL
-    for (i in transformed.variables){
-      assign (varnames.new[i],
-        rescale (get (as.character(call$data)) [[varnames[i]]], binary.inputs))
-      newvars <- cbind (newvars, get(varnames.new[i]))
+    for (i in transformed.variables) {
+      assign(varnames.new[i], rescale(get(as.character(call$data))[[varnames[i]]], 
+                binary.inputs))
+      newvars <- cbind(newvars, get(varnames.new[i]))
     }
-    assign (as.character(call$data),
-      cbind (get(as.character(call$data)), newvars))
+    assign(as.character(call$data), cbind(get(as.character(call$data)), newvars))
   }
-#
+
 # Now call the regression with the new variables
-#
+
   call.new <- call
   L <- sapply (as.list (varnames.new), as.name)
   names(L) <- varnames
@@ -73,8 +65,42 @@ standardize <- function (object, unchanged=NULL,
   formula <- paste (formula[2],formula[1],formula[3])
   formula <- gsub ("factor(z.", "factor(", formula, fixed=TRUE)
   formula <- gsub ("factor(c.", "factor(", formula, fixed=TRUE)
-  formula <- gsub ("| z.", "| ", formula, fixed=TRUE)
-  formula <- gsub ("| c.", "| ", formula, fixed=TRUE)
   call.new$formula <- as.formula (formula) 
   return (eval (call.new))
 }
+
+
+
+
+setMethod("standardize", signature(object = "lm"),
+  function(object, unchanged=NULL, 
+    standardize.y=FALSE, binary.inputs="center")
+{
+  call <- object$call
+  out <- standardize.default(call=call, unchanged=unchanged, 
+    standardize.y=standardize.y, binary.inputs=binary.inputs)
+  return(out)
+}
+)
+
+setMethod("standardize", signature(object = "glm"),
+  function(object, unchanged=NULL, 
+    standardize.y=FALSE, binary.inputs="center")
+{
+  call <- object$call
+  out <- standardize.default(call=call, unchanged=unchanged, 
+    standardize.y=standardize.y, binary.inputs=binary.inputs)
+  return(out)
+}
+)
+
+setMethod("standardize", signature(object = "mer"),
+  function(object, unchanged=NULL, 
+    standardize.y=FALSE, binary.inputs="center")
+{
+  call <- object@call
+  out <- standardize.default(call=call, unchanged=unchanged, 
+    standardize.y=standardize.y, binary.inputs=binary.inputs)
+  return(out)
+}
+)
